@@ -4,8 +4,9 @@
 .. _LaTeX: http://www.latex-project.org/
 """
 __author__ = "Kevin Davies"
-__version__ = "0.1"
 __email__ = "kdavies4@gmail.com"
+__copyright__ = "Copyright 2012, Georgia Tech Research Corporation"
+__license__ = "BSD-compatible (see LICENSE.txt)"
 
 
 def label_number(quantity="", unit=None, times='\,', per='\,/\,', roman=False):
@@ -167,7 +168,7 @@ def label_quantity(number, unit='', format='%G', times='\,', roman=False):
                 pow1000 = e/3
             else:
                 pow1000 = -(-e/3)
-            pow1000 = int(pow1000) # **Why is this necessary in Python 3?
+            pow1000 = int(pow1000) # TODO:  Why is this necessary in Python 3?
             if -8 <= pow1000 <= 8:
                 unit = _si_prefix(pow1000) + unit
                 numstr, exponent = (format % (number/1000**pow1000)).split('e')
